"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultExperimentalOptions = void 0;
const unleash_client_1 = require("unleash-client");
const util_1 = require("../util");
const variant_1 = require("unleash-client/lib/variant");
const flags = {
    anonymiseEventLog: false,
    enableLicense: false,
    enableLicenseChecker: false,
    embedProxy: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_EMBED_PROXY, true),
    embedProxyFrontend: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_EMBED_PROXY_FRONTEND, true),
    responseTimeWithAppNameKillSwitch: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_RESPONSE_TIME_WITH_APP_NAME_KILL_SWITCH, false),
    maintenanceMode: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_MAINTENANCE_MODE, false),
    messageBanner: {
        name: 'message-banner',
        enabled: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_MESSAGE_BANNER, false),
        payload: {
            type: unleash_client_1.PayloadType.JSON,
            value: process.env.UNLEASH_EXPERIMENTAL_MESSAGE_BANNER_PAYLOAD ?? '',
        },
    },
    featuresExportImport: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_FEATURES_EXPORT_IMPORT, true),
    caseInsensitiveInOperators: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_CASE_INSENSITIVE_IN_OPERATORS, false),
    strictSchemaValidation: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_STRICT_SCHEMA_VALIDTION, false),
    personalAccessTokensKillSwitch: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_PAT_KILL_SWITCH, false),
    migrationLock: (0, util_1.parseEnvVarBoolean)(process.env.MIGRATION_LOCK, true),
    demo: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_DEMO, false),
    googleAuthEnabled: (0, util_1.parseEnvVarBoolean)(process.env.GOOGLE_AUTH_ENABLED, false),
    disableBulkToggle: (0, util_1.parseEnvVarBoolean)(process.env.DISABLE_BULK_TOGGLE, false),
    disableNotifications: (0, util_1.parseEnvVarBoolean)(process.env.DISABLE_NOTIFICATIONS, false),
    filterInvalidClientMetrics: (0, util_1.parseEnvVarBoolean)(process.env.FILTER_INVALID_CLIENT_METRICS, false),
    disableMetrics: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_DISABLE_METRICS, false),
    signals: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_SIGNALS, false),
    automatedActions: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_AUTOMATED_ACTIONS, false),
    celebrateUnleash: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_CELEBRATE_UNLEASH, false),
    featureSearchFeedback: {
        name: 'withText',
        enabled: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_FEATURE_SEARCH_FEEDBACK, false),
        payload: {
            type: unleash_client_1.PayloadType.JSON,
            value: process.env
                .UNLEASH_EXPERIMENTAL_FEATURE_SEARCH_FEEDBACK_PAYLOAD ?? '',
        },
    },
    featureSearchFeedbackPosting: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_FEATURE_SEARCH_FEEDBACK_POSTING, false),
    encryptEmails: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_ENCRYPT_EMAILS, false),
    edgeBulkMetrics: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_EDGE_BULK_METRICS, false),
    extendedUsageMetrics: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_EXTENDED_USAGE_METRICS, false),
    adminTokenKillSwitch: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_ADMIN_TOKEN_KILL_SWITCH, false),
    executiveDashboard: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_EXECUTIVE_DASHBOARD, false),
    executiveDashboardUI: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_EXECUTIVE_DASHBOARD_UI, false),
    outdatedSdksBanner: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_OUTDATED_SDKS_BANNER, false),
    feedbackComments: {
        name: 'feedbackComments',
        enabled: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_FEEDBACK_COMMENTS, false),
        payload: {
            type: unleash_client_1.PayloadType.JSON,
            value: process.env.UNLEASH_EXPERIMENTAL_FEEDBACK_COMMENTS_PAYLOAD ??
                '',
        },
    },
    showInactiveUsers: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_SHOW_INACTIVE_USERS, false),
    useMemoizedActiveTokens: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_MEMOIZED_ACTIVE_TOKENS, false),
    killScheduledChangeRequestCache: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_KILL_SCHEDULED_CHANGE_REQUEST_CACHE, false),
    collectTrafficDataUsage: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_COLLECT_TRAFFIC_DATA_USAGE, false),
    displayTrafficDataUsage: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_DISPLAY_TRAFFIC_DATA_USAGE, false),
    userAccessUIEnabled: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_USER_ACCESS_UI_ENABLED, false),
    disableUpdateMaxRevisionId: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_DISABLE_SCHEDULED_CACHES, false),
    disablePublishUnannouncedEvents: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_DISABLE_SCHEDULED_CACHES, false),
    queryMissingTokens: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_QUERY_MISSING_TOKENS, false),
    scimApi: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_SCIM_API, false),
    displayEdgeBanner: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_DISPLAY_EDGE_BANNER, false),
    responseTimeMetricsFix: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_RESPONSE_TIME_METRICS_FIX, false),
    projectOverviewRefactor: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_PROJECT_OVERVIEW_REFACTOR, false),
    disableShowContextFieldSelectionValues: (0, util_1.parseEnvVarBoolean)(process.env
        .UNLEASH_EXPERIMENTAL_DISABLE_SHOW_CONTEXT_FIELD_SELECTION_VALUES, false),
    projectOverviewRefactorFeedback: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_PROJECT_OVERVIEW_REFACTOR_FEEDBACK, false),
    featureLifecycle: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_FEATURE_LIFECYCLE, false),
    projectListFilterMyProjects: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_PROJECTS_LIST_MY_PROJECTS, false),
    parseProjectFromSession: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_PARSE_PROJECT_FROM_SESSION, false),
    createProjectWithEnvironmentConfig: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_CREATE_PROJECT_WITH_ENVIRONMENT_CONFIG, false),
    projectsListNewCards: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_PROJECTS_LIST_NEW_CARDS, false),
    newCreateProjectUI: (0, util_1.parseEnvVarBoolean)(process.env.UNLEASH_EXPERIMENTAL_NEW_CREATE_PROJECT_UI, false),
};
exports.defaultExperimentalOptions = {
    flags,
    externalResolver: {
        isEnabled: () => false,
        getVariant: () => (0, variant_1.getDefaultVariant)(),
    },
};
//# sourceMappingURL=experimental.js.map